function [ answer ] = runEventOnStation(station, year, dayOfYear, hour, minute, second, arrivalHour, arrivalMin, arrivalSec)
%RUNEVENTONSTATION Summary of this function goes here
%   Detailed explanation goes here
X = xlsread('FinLocalEarthq.xls');
[locations stations] = xlsread('stations.xls');

files = dir(['mseeds/*.' station '.*.*.*.' num2str(year) '.' num2str(dayOfYear) '.mseed']);
D = rdmseed(['mseeds/' files(1).name]);

files(1).name

Dd = datevec(D(1).t(1));
month = Dd(2); dayOfMonth = Dd(3);

ind = find(ismember(X(:, 1:5), [year month dayOfMonth (100*hour+minute) second], 'rows') == 1);
X2 = X(ind, :);

magnitude = X2(1, 9);

% event window:
% hour1:minute1:second1 -- hour2:minute2:second2
hour1 = hour; minute1 = minute - 15; second1 = second;
if minute1 < 0, hour1 = hour1 - 1; minute1 = minute1 + 60; end

hour2 = hour; minute2 = minute + 30; second2 = second;
if minute2 > 59, hour2 = hour2 + 1; minute2 = minute2 - 60; end

% datenumbers of the start and the end of the event window:
dn1 = datenum([year month dayOfMonth hour1 minute1 second1]);
dn2 = datenum([year month dayOfMonth hour2 minute2 second2]);

dnOrigin = datenum([year month dayOfMonth hour minute second]);

k1 = 1;
while D(k1).t(end) < dn1
    if k1 < size(D, 2)
        k1 = k1 + 1;
    else
        break;
    end
end

k2 = k1; k0 = k1;

while D(k2).t(1) < dn2
    if D(k0).t(end) < dnOrigin && k0 < size(D, 2)
        k0 = k0 + 1;
    end
    if k2 < size(D, 2)
        k2 = k2 + 1;
    else
        break;
    end
  end

j0 = 1;

while D(k0).t(j0) < dnOrigin
    if j0 < size(D(k0).t, 1)
        j0 = j0 + 1;
    else
        break;
    end
end

E = [cat(1, D(k1:k2).t) cat(1, D(k1:k2).d)];


% Event Depth
eventDepth = X2(1, 8);

% Distance
lat1 = X2(1, 6); lon1 = X2(1, 7); %event location 
ind = strmatch(strtrim(D(1).StationIdentifierCode), stations, 'exact') - 1;
lat2 = locations(ind, 1); lon2 = locations(ind, 2); %station location
epicentralDistance = 2 * pi * 6371 * distance(lat1, lon1, lat2, lon2) / 360;

% Travel time
t = datenum([year month dayOfMonth arrivalHour arrivalMin arrivalSec]);
travelTime = (t - dnOrigin) * 24 * 60 * 60;

freq = D(1).SampleRate;

deltaT = 1 / freq;
Tbegin = -15 * 60;
Tend = 30 * 60;
d = E(:, 2);
difference = datevec(t - datenum([year month dayOfMonth hour minute second]));
Tarrival = difference(5) * 60 + difference(6);

d = prepareData(deltaT, Tbegin, Tend, d);

scales = 1:100;
[r, mn, chosenscale, chosenN, stds, ulNoise] = choose(deltaT, Tbegin, Tarrival, d, scales); % may put noise cutout outside the function, to use it with another data chunk
display('rolling on whole thing')
ul = roll(r, chosenN, [d(:,1)/chosenscale d(:,2)]); % data must be already scaled for roll!
tix = ceil(r * chosenscale / deltaT); % the offset from left

t1 = Tarrival - 30;
t2 = Tarrival + 60;
T1 = find(d(:, 1) >= t1, 1) - tix;
T2 = find(d(:, 1) >= t2, 1) - 1 - tix;

m = max(ul(T1:T2));

ticksWhereHit0 = tix +...  
                 find(ul == m)+... % this is where max of output is
                 find(ul(find(ul == m):end) < mn, 1); % first time ul goes below mn, all in ticks
answer = d(ticksWhereHit0, 1) - Tarrival; % coda length in seconds

ul = [NaN(1, tix-1) ul NaN(1, tix)];

naa = mean(d(ticksWhereHit0:end,2)); % mean noise after answer

% Output
figure; plot(d(:, 1), d(:, 2), '.', 'Color', [.5 .5 .5], 'MarkerSize', 2); hold on;
plot([Tarrival Tarrival ], [min(d(:, 2)) max(d(:, 2))], 'Color', [.5 .5 .5] );
plot([Tbegin Tend], [mn mn], 'b');
plot(d(:, 1), ul);
if ~isnan(answer),
    plot([answer+Tarrival answer+Tarrival], [min(d(:, 2)) max(d(:, 2))]);
    plot([answer+Tarrival max(d(:, 1))], [naa naa]);
end;

last1000 = d(end-1000:end, :); plot([min(last1000(:, 1)) max(last1000(:, 1))], mean(last1000(:, 2)) * [1 1], 'r');

set(gcf,'renderer', 'zbuffer');

% save the output figure:
saveas(gcf, ['output/' strtrim(D(1).StationIdentifierCode) '.' int2str(year) '.' int2str(month) '.' int2str(dayOfMonth) '.' int2str(hour) '.' int2str(minute) '_' num2str(chosenscale) '.png'])

% Saving ul:
ul2 = ul';
t2 = d(:,1) + travelTime;
ul2 = [t2 ul2];
save(['output/ul_' strtrim(D(1).StationIdentifierCode) '.' int2str(year) '.' int2str(month) '.' int2str(dayOfMonth) '.' int2str(hour) '.' int2str(minute) '.txt'], 'ul2', '-ascii', '-double')

% Saving the output:
fileID = fopen(['output/output.txt'], 'a');
fprintf(fileID, '%i %i %i %i %i %.3f %s %.1f %s %i %i %f %.3f %f %f\r\n', ...
        year, ... % year
        month, ... % month
        dayOfMonth, ... % day
        hour, ... % hours
        minute, ... % minutes
        second, ... % seconds
        datestr(t, 'HH MM SS.FFF'), ... % arrival_time
        eventDepth, ... % event depth
        strtrim(D(1).StationIdentifierCode), ... % station id code
        freq, ... % sample rate
        dayOfYear, ... % julian day
        epicentralDistance, ... % distance
        travelTime, ... % travel time
        answer, ... % answer
        magnitude ... % magnitude
        );
fclose(fileID);

end

